@@ -51,12 +51,6 @@ class DepoSetting(BaseModel):
     day_count: DayCount = DayCount.act_act_act365
     eom: bool = False
 
-    @validator('start_basis')
-    def valid_start_basis(cls, v): 
-        if v not in StartBasis:
-            raise ValueError
-        return  v
-
 
 class BondSetting(BaseModel):
     frequency: Frequency = Frequency.semi_annual
