@@ -1,3 +1,4 @@
+from fpql.bonds import get_qlfixedratebond
 import QuantLib as ql 
 from fpql.ql_enums import *
 from fpql.pymodels import *
@@ -72,8 +73,8 @@ def sample_bondinfo():
 
     setting = BondSetting(**bondsetting)
 
-    bonddata = {"issue_date": "2021-01-05", 
-                "maturity": "2026-01-05", 
+    bonddata = {"issue_date": "2021-07-29", 
+                "maturity": "2026-07-29", 
                 "settings": setting, 
                 "coupon": 5.0,
                 "face_value": 10_000_000
@@ -167,6 +168,7 @@ def sample_FRB():
 # equivalent to using ql.AmortizingFixedRateBond
 def sample_qlbond():
     thebond, setting = sample_bondinfo()
+    abond = get_qlfixedratebond(thebond, setting,ql.WeekendsOnly())
     ql_period = ql.Period(ql_freq_tenor[setting.frequency])
     #print(ql_period)
     #1. Create Schedule
